==> 0.0.5.tar.gz: lib/models/video_page.dart <==
class VideoPage {
  ///Get video id from video page
  String? videoId;

  ///Get video title from video page
  String? title;

  ///Get video date from video page
  String? date;

  ///Get video description from video page
  String? description;

  ///Get video channel name from video page
  String? channelName;

  ///Get video views count as string from video page
  String? viewCount;

  ///Get video likes count as string from video page
  String? likeCount;

  ///Get video unlikes count as string from video page
  String? unlikeCount;

  ///Get video channel thumbnail from video page
  String? channelThumb;

  ///Get channel id from video page
  String? channelId;

  ///Get channel subscribes count as string from video page
  String? subscribeCount;

  VideoPage(
      {this.videoId,
      this.title,
      this.channelName,
      this.viewCount,
      this.subscribeCount,
      this.likeCount,
      this.unlikeCount,
      this.date,
      this.description,
      this.channelThumb,
      this.channelId});

  factory VideoPage.fromMap(Map<String, dynamic>? map, String videoId) {
    var likes = map?['results']['results']['contents'][0]
                ['videoPrimaryInfoRenderer']['videoActions']['menuRenderer']
            ['topLevelButtons'][0]['segmentedLikeDislikeButtonRenderer']
        ['likeButton']['toggleButtonRenderer']['defaultText']['simpleText'];
    var views = map?['results']['results']['contents'][0]
            ['videoPrimaryInfoRenderer']['viewCount']['videoViewCountRenderer']
        ['viewCount']['runs'];
    var oldViews = map?['results']['results']['contents'][0]
            ['videoPrimaryInfoRenderer']['viewCount']['videoViewCountRenderer']
        ['shortViewCount'];
        
    String? viewers;
    String? likers;

    if (likes == null) {
      likers = '0';
    } else {
      likers = likes;
    }
    if (views != null) {
      viewers = views?[0]['text'] + views?[1]['text'];
    } else if (oldViews != null) {
      viewers = oldViews['simpleText'];
    } else {
      viewers = map?['results']['results']['contents'][0]
              ['videoPrimaryInfoRenderer']['viewCount']
          ['videoViewCountRenderer']['viewCount']['simpleText'];
    }
    return VideoPage(
        videoId: videoId,
        title: map?['results']['results']['contents'][0]
            ['videoPrimaryInfoRenderer']['title']['runs'][0]['text'],
        channelName: map?['results']['results']['contents'][1]['videoSecondaryInfoRenderer']
            ['owner']['videoOwnerRenderer']['title']['runs'][0]['text'],
        viewCount: viewers,
        subscribeCount: map?['results']?['results']?['contents']?[1]
                ?['videoSecondaryInfoRenderer']?['owner']?['videoOwnerRenderer']
            ?['subscriberCountText']?['simpleText'],
        likeCount: likers,
        unlikeCount: '',
        description: map?['results']?['results']?['contents']?[1]
            ?['videoSecondaryInfoRenderer']?['attributedDescription']?['content'],
        date: map?['results']['results']['contents'][0]['videoPrimaryInfoRenderer']['dateText']['simpleText'],
        channelThumb: map?['results']['results']['contents'][1]['videoSecondaryInfoRenderer']['owner']['videoOwnerRenderer']['thumbnail']['thumbnails'][1]['url'],
        channelId: map?['results']['results']['contents'][1]['videoSecondaryInfoRenderer']['owner']['videoOwnerRenderer']['navigationEndpoint']['browseEndpoint']['browseId']);
  }
}

==> 0.0.6.tar.gz: lib/models/video_page.dart <==
class VideoPage {
  ///Get video id from video page
  String? videoId;

  ///Get video title from video page
  String? title;

  ///Get video date from video page
  String? date;

  ///Get video description from video page
  String? description;

  ///Get video channel name from video page
  String? channelName;

  ///Get video views count as string from video page
  String? viewCount;

  ///Get video likes count as string from video page
  String? likeCount;

  ///Get video unlikes count as string from video page
  String? unlikeCount;

  ///Get video channel thumbnail from video page
  String? channelThumb;

  ///Get channel id from video page
  String? channelId;

  ///Get channel subscribes count as string from video page
  String? subscribeCount;

  VideoPage(
      {this.videoId,
      this.title,
      this.channelName,
      this.viewCount,
      this.subscribeCount,
      this.likeCount,
      this.unlikeCount,
      this.date,
      this.description,
      this.channelThumb,
      this.channelId});

  factory VideoPage.fromMap(Map<String, dynamic>? map, String videoId) {
    var likes = map?['results']['results']['contents'][0]
            ['videoPrimaryInfoRenderer']['videoActions']['menuRenderer']
        ['topLevelButtons'][0];
    var views = map?['results']['results']['contents'][0]
            ['videoPrimaryInfoRenderer']['viewCount']['videoViewCountRenderer']
        ['viewCount']['runs'];
    var oldViews = map?['results']['results']['contents'][0]
            ['videoPrimaryInfoRenderer']['viewCount']['videoViewCountRenderer']
        ['shortViewCount'];

    String? viewers;
    String? likers;

    if (likes == []) {
      likers = '0';
    } else {
      likers = likes['segmentedLikeDislikeButtonViewModel']
                ['likeButtonViewModel']['likeButtonViewModel']
            ['toggleButtonViewModel']['toggleButtonViewModel']
        ['defaultButtonViewModel']['buttonViewModel']['title'];
    }
    if (views != null) {
      viewers = views?[0]['text'] + views?[1]['text'];
    } else if (oldViews != null) {
      viewers = oldViews['simpleText'];
    } else {
      viewers = map?['results']['results']['contents'][0]
              ['videoPrimaryInfoRenderer']['viewCount']
          ['videoViewCountRenderer']['viewCount']['simpleText'];
    }
    return VideoPage(
        videoId: videoId,
        title: map?['results']['results']['contents'][0]
            ['videoPrimaryInfoRenderer']['title']['runs'][0]['text'],
        channelName: map?['results']['results']['contents'][1]['videoSecondaryInfoRenderer']
            ['owner']['videoOwnerRenderer']['title']['runs'][0]['text'],
        viewCount: viewers,
        subscribeCount: map?['results']?['results']?['contents']?[1]
                ?['videoSecondaryInfoRenderer']?['owner']?['videoOwnerRenderer']
            ?['subscriberCountText']?['simpleText'],
        likeCount: likers,
        unlikeCount: '',
        description: map?['results']?['results']?['contents']?[1]
            ?['videoSecondaryInfoRenderer']?['attributedDescription']?['content'],
        date: map?['results']['results']['contents'][0]['videoPrimaryInfoRenderer']['dateText']['simpleText'],
        channelThumb: map?['results']['results']['contents'][1]['videoSecondaryInfoRenderer']['owner']['videoOwnerRenderer']['thumbnail']['thumbnails'][1]['url'],
        channelId: map?['results']['results']['contents'][1]['videoSecondaryInfoRenderer']['owner']['videoOwnerRenderer']['navigationEndpoint']['browseEndpoint']['browseId']);
  }
}
